#[non_exhaustive]pub enum Code {
Unspecified,
InternalError,
ScanConfigIssue,
AuthenticationConfigIssue,
TimedOutWhileScanning,
TooManyRedirects,
TooManyHttpErrors,
UnknownValue(UnknownValue),
}Expand description
Output only. Defines an error reason code. Next id: 8
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value is never used.
InternalError
Indicates that the scan run failed due to an internal server error.
ScanConfigIssue
Indicates a scan configuration error, usually due to outdated ScanConfig settings, such as starting_urls or the DNS configuration.
AuthenticationConfigIssue
Indicates an authentication error, usually due to outdated ScanConfig authentication settings.
TimedOutWhileScanning
Indicates a scan operation timeout, usually caused by a very large site.
TooManyRedirects
Indicates that a scan encountered excessive redirects, either to authentication or some other page outside of the scan scope.
TooManyHttpErrors
Indicates that a scan encountered numerous errors from the web site pages. When available, most_common_http_error_code field indicates the most common HTTP error code encountered during the scan.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Code::value or Code::name.