This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Indicates that a scan discovered an unexpectedly low number of URLs. This
is sometimes caused by complex navigation features or by using a single
URL for numerous pages.
Indicates that too many tests have been generated for the scan. Customer
should try reducing the number of starting URLs, increasing the QPS rate,
or narrowing down the scope of the scan using the excluded patterns.